pub struct AddToken {
pub token_account: Pubkey,
pub mint: Pubkey,
pub user: Pubkey,
pub payer: Option<Pubkey>,
pub system_program: Option<Pubkey>,
}Expand description
Accounts.
Fields
token_account: PubkeyThe token authority account.
mint: PubkeyThe mint account for the token to be added.
user: PubkeyThe pubkey of the user associated with the token account
payer: Option<Pubkey>The account paying for the storage fees.
system_program: Option<Pubkey>The system program
Implementations
Sourceimpl AddToken
impl AddToken
pub fn instruction(&self) -> Instruction
pub fn instruction_with_remaining_accounts( &self, remaining_accounts: &[AccountMeta], ) -> Instruction