pub struct CreateMintInstructionArgs {
pub ticker: String,
pub max_supply: u64,
pub decimals: u8,
}Fields
ticker: Stringmax_supply: u64decimals: u8Trait Implementations
Sourceimpl BorshDeserialize for CreateMintInstructionArgs
impl BorshDeserialize for CreateMintInstructionArgs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateMintInstructionArgs
impl Clone for CreateMintInstructionArgs
Sourcefn clone(&self) -> CreateMintInstructionArgs
fn clone(&self) -> CreateMintInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateMintInstructionArgs
impl Debug for CreateMintInstructionArgs
impl Eq for CreateMintInstructionArgs
impl StructuralPartialEq for CreateMintInstructionArgs