pub struct CreateTokenAccountInstructionArgs {
pub capacity: u8,
}Fields
capacity: u8Trait Implementations
Sourceimpl BorshDeserialize for CreateTokenAccountInstructionArgswhere
u8: BorshDeserialize,
impl BorshDeserialize for CreateTokenAccountInstructionArgswhere
u8: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateTokenAccountInstructionArgswhere
u8: BorshSerialize,
impl BorshSerialize for CreateTokenAccountInstructionArgswhere
u8: BorshSerialize,
Sourceimpl Clone for CreateTokenAccountInstructionArgs
impl Clone for CreateTokenAccountInstructionArgs
Sourcefn clone(&self) -> CreateTokenAccountInstructionArgs
fn clone(&self) -> CreateTokenAccountInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for CreateTokenAccountInstructionArgs
impl PartialEq for CreateTokenAccountInstructionArgs
Sourcefn eq(&self, other: &CreateTokenAccountInstructionArgs) -> bool
fn eq(&self, other: &CreateTokenAccountInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CreateTokenAccountInstructionArgs
impl StructuralPartialEq for CreateTokenAccountInstructionArgs